Buckit Admin CLI

The Buckit Manager CLI provides the bm admin command for performing administrative tasks on your Buckit deployments.

While bm supports any S3-compatible service, bm admin only supports Buckit deployments.

bm admin has the following syntax:

bm admin [FLAGS] COMMAND [ARGUMENTS]

Command Quick reference

The following table lists bm admin commands:

Command

Description

bm admin accesskey

The bm admin accesskey command and its subcommands create and manage Access Keys for internally managed users on a Buckit deployment.

bm admin cluster bucket

The bm admin cluster bucket command and its subcommands provide tools for manually importing and exporting Buckit bucket metadata.

bm admin cluster iam

The bm admin cluster iam command and its subcommands provide tools for manually importing and exporting Buckit identity and access management (IAM) metadata.

bm admin decommission

The bm admin decommission command starts the decommissioning process for a Buckit server pools. Decommissioning is designed for removing an older server pool whose hardware is no longer sufficient or performant compared to the pools in the deployment. Buckit automatically migrates data from the decommissioned pool to the remaining pools in the deployment based on the ratio of free space available in each pool.

bm admin group

The bm admin group command manages groups on a Buckit deployment.

bm admin heal

The bm admin heal command scans for objects that are damaged or corrupted and heals those objects.

bm admin info

The bm admin info command displays information on a Buckit server. For distributed Buckit deployments, bm admin info displays information for each Buckit server in the deployment.

bm admin kms key

The bm admin kms key command performs cryptographic key management operations through the Buckit Key Encryption Service (KES).

bm admin logs

Use the bm admin logs command to show buckit server logs.

bm admin policy

The bm admin policy commands manage policies for use with Buckit Policy-Based Access Control (PBAC). Buckit PBAC uses IAM-compatible policy JSON documents to define rules for accessing resources on a Buckit server.

bm admin prometheus

The bm admin prometheus command and its subcommands provide access to Buckit Prometheus metrics.

bm admin rebalance

The bm admin rebalance command allows starts, monitors, or stops a rebalancing operation on a Buckit deployment. Rebalancing redistributes objects across all pools in the deployment.

bm admin replicate

The bm admin replicate command creates and manages site replication for a set of Buckit peer sites.

Site replication mimics an active-active bucket replication, but for multiple Buckit deployments. Wherever a change occurs to IAM settings, buckets, or objects across the set of sites, the change replicates across all sites in the site replication group.

bm admin scanner

The bm admin scanner commands provide information about the scanner process.

bm admin service

The bm admin service command can restart or unfreeze Buckit servers.

bm admin trace

The bm admin trace command displays API operations occurring on the target Buckit deployment.

bm admin update

The bm admin update command updates all Buckit servers in the deployment. The command also supports using a private mirror server for environments where the deployment does not have public internet access.

bm admin user

The bm admin user command and its subcommands manage Buckit users.

Installation

Install bm with the official Buckit Manager installer:

curl -fsSL https://buckit-io.github.io/bm/install.sh | sh
bm --help

The installer downloads the latest stable build for your operating system and architecture, verifies its SHA-256 checksum, and installs it into your user account.

Install bm with the official Buckit Manager installer:

irm https://buckit-io.github.io/bm/install.ps1 | iex
bm --help

The installer downloads the latest stable build for your operating system and architecture, verifies its SHA-256 checksum, and installs it into your user account.

Quickstart

Ensure that the host machine has bm installed prior to starting this procedure.

Important

The following example temporarily disables the bash history to mitigate the risk of authentication credentials leaking in plain text. This is a basic security measure and does not mitigate all possible attack vectors. Defer to security best practices for your operating system for inputting sensitive information on the command line.

Use the bm alias set command to add the deployment to the bm configuration.

bash +o history
bm alias set <ALIAS> <ENDPOINT> ACCESS_KEY SECRET_KEY
bash -o history

Replace each argument with the required values.

Use the bm admin info command to test the connection to the newly added Buckit deployment:

bm admin info <ALIAS>

Global Options

bm admin supports the same global options as bm. See Global Options.