Buckit Admin CLI
The Buckit Manager CLI provides the bm admin
command for performing administrative tasks on your Buckit deployments.
While bm supports any S3-compatible service,
bm admin only supports Buckit deployments.
bm admin has the following syntax:
bm admin [FLAGS] COMMAND [ARGUMENTS]
Command Quick reference
The following table lists bm admin commands:
Command |
Description |
|---|---|
The |
|
The |
|
The |
|
The |
|
The |
|
The |
|
The |
|
The |
|
Use the |
|
The |
|
The |
|
The |
|
The Site replication mimics an active-active bucket replication, but for multiple Buckit deployments. Wherever a change occurs to IAM settings, buckets, or objects across the set of sites, the change replicates across all sites in the site replication group. |
|
The |
|
The |
|
The |
|
The |
|
The |
Installation
Install bm with the official Buckit Manager installer:
curl -fsSL https://buckit-io.github.io/bm/install.sh | sh
bm --help
The installer downloads the latest stable build for your operating system and architecture, verifies its SHA-256 checksum, and installs it into your user account.
Install bm with the official Buckit Manager installer:
irm https://buckit-io.github.io/bm/install.ps1 | iex
bm --help
The installer downloads the latest stable build for your operating system and architecture, verifies its SHA-256 checksum, and installs it into your user account.
Quickstart
Ensure that the host machine has bm
installed prior to starting this procedure.
Important
The following example temporarily disables the bash history to mitigate the risk of authentication credentials leaking in plain text. This is a basic security measure and does not mitigate all possible attack vectors. Defer to security best practices for your operating system for inputting sensitive information on the command line.
Use the bm alias set command to add the
deployment to the bm configuration.
bash +o history
bm alias set <ALIAS> <ENDPOINT> ACCESS_KEY SECRET_KEY
bash -o history
Replace each argument with the required values.
Use the bm admin info command to test the connection to
the newly added Buckit deployment:
bm admin info <ALIAS>
Global Options
bm admin supports the same global options as bm.
See Global Options.